@@ -103,7 +103,7 @@ class BetaCalibrationDependent(AbstractCalibration):
     ----------
     .. [1] Fabian Küppers, Jan Kronenberger, Amirhossein Shantia and Anselm Haselhoff:
        "Multivariate Confidence Calibration for Object Detection."
-       The IEEE Conference on Computer Vision and Pattern Recognition (CVPR) Workshops, 2020, in press.
+       The IEEE/CVF Conference on Computer Vision and Pattern Recognition (CVPR) Workshops.
 
     .. [2] Libby, David L., and Melvin R. Novick:
        "Multivariate generalized beta distributions with applications to utility assessment"
@@ -393,7 +393,8 @@ class BetaCalibrationDependent(AbstractCalibration):
         best_loss = np.infty
 
         # use tqdm logger to pipe tqdm output to logger
-        tqdm_logger = TqdmHandler(logger=self.logger, level=logging.INFO)
+        logger = logging.getLogger(__name__)
+        tqdm_logger = TqdmHandler(logger=logger, level=logging.INFO)
         with tqdm(total=num_epochs * num_batches, file=tqdm_logger) as pbar:
             for epoch in range(num_epochs):
 
